# Wasot Principles

These principles guide the design of Wasot's [architecture](./architecture.md) and [data model](./wasot_and_xml.md). For practical examples of how these apply, see [use cases](./use_cases.md).

* Humans have agency and control
* Tools AND Humans are first class citizens
* Give freedom
* Get out of the way
* Everything should work and for something that never heart wasot
* Wasot is not important, the user, its tools and its content are.
* Scale down and up
* Take as little memory as possible gives freedom
* Don't be wasteful